==> ogre-14.3.4-1-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/_ogre_texture_8h.js <==
var _ogre_texture_8h =
[
    [ "Ogre::TextureUsage", "group___resources.html#gaf140ec886884a864abc74a7556f8bf67", [
      [ "Ogre::TU_STATIC", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67a375858a86cadfb2a4d20fe837fdb85b3", null ],
      [ "Ogre::TU_DYNAMIC", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67ad18031f12c4bd22f73b09a4536e99df5", null ],
      [ "Ogre::TU_WRITE_ONLY", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67af7b0d53154ffc7c389404dc51c792655", null ],
      [ "Ogre::TU_STATIC_WRITE_ONLY", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67a2b9d0399c32f2098957ebc089c337e55", null ],
      [ "Ogre::TU_DYNAMIC_WRITE_ONLY", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67ac26eda030d21e0491461edea89394493", null ],
      [ "Ogre::TU_DYNAMIC_WRITE_ONLY_DISCARDABLE", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67a79920182637c94fabcf834950096483f", null ],
      [ "Ogre::TU_AUTOMIPMAP", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67a7c14cc95a59af42a63eb33fc9de05d27", null ],
      [ "Ogre::TU_RENDERTARGET", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67ae1661d9846a9b4e83c2e4cd99fc6ad9d", null ],
      [ "Ogre::TU_NOT_SAMPLED", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67a01b70f2cf9ba057c62aa554af7f5f2a8", null ],
      [ "Ogre::TU_UNORDERED_ACCESS", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67aaaa1e44020b4fcc25600b423f45cd227", null ],
      [ "Ogre::TU_DEFAULT", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67acaa45fe77d1becf4c5bd353bc2aa764b", null ],
      [ "Ogre::TU_UAV_NOT_SRV", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67a705be8b4d48b62f98e1cd5d70c2a16a8", null ],
      [ "Ogre::TU_NOT_SRV", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67aeaa879e353bc503f741a0a0671b35c15", null ],
      [ "Ogre::TU_NOTSHADERRESOURCE", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67a186a9408e017e08e63c56db55da7f09f", null ],
      [ "Ogre::TU_UAV", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67a85ca4e5cb922c3a2381ed5eed01c0cf1", null ]
    ] ],
    [ "Ogre::TextureAccess", "group___resources.html#ga12b16f4465fec1b8fff40c719e2aa458", [
      [ "Ogre::TA_READ", "group___resources.html#gga12b16f4465fec1b8fff40c719e2aa458a183a8dcf97daf2dcd3c7984c8c09040e", null ],
      [ "Ogre::TA_WRITE", "group___resources.html#gga12b16f4465fec1b8fff40c719e2aa458a8d8ea745f3af07796f15e9608d3e7a2f", null ],
      [ "Ogre::TA_READ_WRITE", "group___resources.html#gga12b16f4465fec1b8fff40c719e2aa458a36eb7ddb2aa3dfcc79147c4f4d803ae6", null ]
    ] ],
    [ "Ogre::TextureType", "group___resources.html#gaac3431531c3258e3c1c86ef8a4c06228", [
      [ "Ogre::TEX_TYPE_1D", "group___resources.html#ggaac3431531c3258e3c1c86ef8a4c06228a18bf88d3a14ba28d6602689e398416bd", null ],
      [ "Ogre::TEX_TYPE_2D", "group___resources.html#ggaac3431531c3258e3c1c86ef8a4c06228af1f732018f5a2a7d35233e2ceeb4ee0e", null ],
      [ "Ogre::TEX_TYPE_3D", "group___resources.html#ggaac3431531c3258e3c1c86ef8a4c06228aa80e2545e817591a0b4547f987987d43", null ],
      [ "Ogre::TEX_TYPE_CUBE_MAP", "group___resources.html#ggaac3431531c3258e3c1c86ef8a4c06228ae295fe0fa26623b66cc023f462962344", null ],
      [ "Ogre::TEX_TYPE_2D_ARRAY", "group___resources.html#ggaac3431531c3258e3c1c86ef8a4c06228a11589b2d4fbe6213dcdaf4e78894a3a7", null ],
      [ "Ogre::TEX_TYPE_EXTERNAL_OES", "group___resources.html#ggaac3431531c3258e3c1c86ef8a4c06228a1a31bbe700e223257fb2d18afcb14d73", null ]
    ] ],
    [ "Ogre::TextureMipmap", "group___resources.html#ga528ce4f4c67c9b043e1f0b8bb3cdf255", [
      [ "Ogre::MIP_UNLIMITED", "group___resources.html#gga528ce4f4c67c9b043e1f0b8bb3cdf255a5a6b498127bf3fa219dadfdaaa50b9dd", null ],
      [ "Ogre::MIP_DEFAULT", "group___resources.html#gga528ce4f4c67c9b043e1f0b8bb3cdf255a56eea45719de5246f4ea9b8e8b54921d", null ]
    ] ]
];

==> ogre-14.4.1-2-x86_64.pkg.tar.zst: usr/share/doc/OGRE/api/html/_ogre_texture_8h.js <==
var _ogre_texture_8h =
[
    [ "Ogre::TextureUsage", "group___resources.html#gaf140ec886884a864abc74a7556f8bf67", [
      [ "Ogre::TU_STATIC", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67a375858a86cadfb2a4d20fe837fdb85b3", null ],
      [ "Ogre::TU_DYNAMIC", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67ad18031f12c4bd22f73b09a4536e99df5", null ],
      [ "Ogre::TU_WRITE_ONLY", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67af7b0d53154ffc7c389404dc51c792655", null ],
      [ "Ogre::TU_STATIC_WRITE_ONLY", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67a2b9d0399c32f2098957ebc089c337e55", null ],
      [ "Ogre::TU_DYNAMIC_WRITE_ONLY", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67ac26eda030d21e0491461edea89394493", null ],
      [ "Ogre::TU_DYNAMIC_WRITE_ONLY_DISCARDABLE", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67a79920182637c94fabcf834950096483f", null ],
      [ "Ogre::TU_AUTOMIPMAP", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67a7c14cc95a59af42a63eb33fc9de05d27", null ],
      [ "Ogre::TU_RENDERTARGET", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67ae1661d9846a9b4e83c2e4cd99fc6ad9d", null ],
      [ "Ogre::TU_NOT_SAMPLED", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67a01b70f2cf9ba057c62aa554af7f5f2a8", null ],
      [ "Ogre::TU_UNORDERED_ACCESS", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67aaaa1e44020b4fcc25600b423f45cd227", null ],
      [ "Ogre::TU_TARGET_ALL_LAYERS", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67ac50d3ddf030bb6a15af8454d27c73fe8", null ],
      [ "Ogre::TU_DEFAULT", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67acaa45fe77d1becf4c5bd353bc2aa764b", null ],
      [ "Ogre::TU_UAV_NOT_SRV", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67a705be8b4d48b62f98e1cd5d70c2a16a8", null ],
      [ "Ogre::TU_NOT_SRV", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67aeaa879e353bc503f741a0a0671b35c15", null ],
      [ "Ogre::TU_NOTSHADERRESOURCE", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67a186a9408e017e08e63c56db55da7f09f", null ],
      [ "Ogre::TU_UAV", "group___resources.html#ggaf140ec886884a864abc74a7556f8bf67a85ca4e5cb922c3a2381ed5eed01c0cf1", null ]
    ] ],
    [ "Ogre::TextureAccess", "group___resources.html#ga12b16f4465fec1b8fff40c719e2aa458", [
      [ "Ogre::TA_READ", "group___resources.html#gga12b16f4465fec1b8fff40c719e2aa458a183a8dcf97daf2dcd3c7984c8c09040e", null ],
      [ "Ogre::TA_WRITE", "group___resources.html#gga12b16f4465fec1b8fff40c719e2aa458a8d8ea745f3af07796f15e9608d3e7a2f", null ],
      [ "Ogre::TA_READ_WRITE", "group___resources.html#gga12b16f4465fec1b8fff40c719e2aa458a36eb7ddb2aa3dfcc79147c4f4d803ae6", null ]
    ] ],
    [ "Ogre::TextureType", "group___resources.html#gaac3431531c3258e3c1c86ef8a4c06228", [
      [ "Ogre::TEX_TYPE_1D", "group___resources.html#ggaac3431531c3258e3c1c86ef8a4c06228a18bf88d3a14ba28d6602689e398416bd", null ],
      [ "Ogre::TEX_TYPE_2D", "group___resources.html#ggaac3431531c3258e3c1c86ef8a4c06228af1f732018f5a2a7d35233e2ceeb4ee0e", null ],
      [ "Ogre::TEX_TYPE_3D", "group___resources.html#ggaac3431531c3258e3c1c86ef8a4c06228aa80e2545e817591a0b4547f987987d43", null ],
      [ "Ogre::TEX_TYPE_CUBE_MAP", "group___resources.html#ggaac3431531c3258e3c1c86ef8a4c06228ae295fe0fa26623b66cc023f462962344", null ],
      [ "Ogre::TEX_TYPE_2D_ARRAY", "group___resources.html#ggaac3431531c3258e3c1c86ef8a4c06228a11589b2d4fbe6213dcdaf4e78894a3a7", null ],
      [ "Ogre::TEX_TYPE_EXTERNAL_OES", "group___resources.html#ggaac3431531c3258e3c1c86ef8a4c06228a1a31bbe700e223257fb2d18afcb14d73", null ]
    ] ],
    [ "Ogre::TextureMipmap", "group___resources.html#ga528ce4f4c67c9b043e1f0b8bb3cdf255", [
      [ "Ogre::MIP_UNLIMITED", "group___resources.html#gga528ce4f4c67c9b043e1f0b8bb3cdf255a5a6b498127bf3fa219dadfdaaa50b9dd", null ],
      [ "Ogre::MIP_DEFAULT", "group___resources.html#gga528ce4f4c67c9b043e1f0b8bb3cdf255a56eea45719de5246f4ea9b8e8b54921d", null ]
    ] ]
];
